@@ -138,6 +138,7 @@ STDLIB_NAMES = set((
     "imgfile",
     "imghdr",
     "imp",
+    "importlib",
     "imputil",
     "inspect",
     "io",
@@ -314,19 +315,7 @@ STDLIB_NAMES = set((
     "winsound",
     "wsgiref",
     "xdrlib",
-    "xml.dom",
-    "xml.dom.minidom",
-    "xml.dom.pulldom",
-    "xml.etree.ElementTree",
-    "xml.parsers.expat",
-    "xmlrpc",
-    "xmlrpc.client",
-    "xmlrpclib",
-    "xmlrpc.server",
-    "xml.sax",
-    "xml.sax.handler",
-    "xml.sax.saxutils",
-    "xml.sax.xmlreader",
+    "xml",
     "zipfile",
     "zipimport",
     "zlib",
